#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 spoon
version:              0.3.1
visibility:           public
id:                   spoon-0.3.1-IFvGPwkAb1zGTwlUlGt2G6
key:                  spoon-0.3.1-IFvGPwkAb1zGTwlUlGt2G6
license:              BSD-3-Clause
copyright:            2009 Matt Morrow & Dan Peebles, 2013 Liyang HU
maintainer:           Liyang HU <spoon@liyang.hu>
author:               Matt Morrow, Dan Peebles, Liyang HU
stability:            experimental
synopsis:             Catch errors thrown from pure computations.
description:
    Takes an error-throwing expression and puts it back in the Maybe it belongs in.

category:             Error handling
abi:                  aa0f9c66cce9b8ad7b29e260fcf1fd72
exposed:              True
exposed-modules:      Control.Spoon
import-dirs:          /usr/lib/ghc-8.10.5/site-local/spoon-0.3.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/spoon-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/spoon-0.3.1
hs-libraries:         HSspoon-0.3.1-IFvGPwkAb1zGTwlUlGt2G6
depends:              base-4.14.2.0 deepseq-1.4.4.0
haddock-interfaces:   /usr/share/doc/haskell-spoon/html/spoon.haddock
haddock-html:         /usr/share/doc/haskell-spoon/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

